@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.027
+This document describes Attean::API::Iterator version 0.030
 
 =head1 DESCRIPTION
 
@@ -94,7 +94,7 @@ elements from the referent.
 
 =cut
 
-package Attean::API::Iterator 0.027 {
+package Attean::API::Iterator 0.030 {
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
 	use Carp qw(confess);
@@ -276,7 +276,7 @@ Print each item as it is consumed (with the string generated by C<< as_string >>
 	}
 }
 
-package Attean::API::StringyItemIterator 0.027 {
+package Attean::API::StringyItemIterator 0.030 {
 	use Moo::Role;
 	sub uniq {
 		my $self	= shift;
@@ -289,7 +289,7 @@ package Attean::API::StringyItemIterator 0.027 {
 	}
 }
 
-package Attean::API::RepeatableIterator 0.027 {
+package Attean::API::RepeatableIterator 0.030 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -316,7 +316,6 @@ package Attean::API::RepeatableIterator 0.027 {
 	sub size {
 		my $self	= shift;
 		my @elements	= $self->elements;
-		warn 'RepeatableIterator->size';
 		return scalar(@elements);
 	}
 	
@@ -332,7 +331,7 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.027 {
+package Attean::API::ResultOrTermIterator 0.030 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef Str);
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
@@ -360,19 +359,14 @@ package Attean::API::ResultOrTermIterator 0.027 {
 		Attean::CodeIterator->new(
 			item_type => $iter->item_type,
 			generator => sub {
-				while (1) {
-					my $item	= $iter->next();
-					return unless defined($item);
-					local($_)	= $item;
-					return $item if ($block->($item));
-				}
+				return $iter->next();
 			},
 			variables => $self->variables,
 		);
 	};
 }
 
-package Attean::API::StatementIterator 0.027 {
+package Attean::API::StatementIterator 0.030 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	with 'Attean::API::StringyItemIterator';
@@ -381,34 +375,31 @@ package Attean::API::StatementIterator 0.027 {
 	sub matching_pattern {
 		my $self	= shift;
 		my @nodes	= @_;
+		
+		if (scalar(@nodes) == 1 and $nodes[0]->does('Attean::API::QuadPattern')) {
+			my $pattern	= $nodes[0];
+			@nodes	= $pattern->values;
+		}
 
 		my %bound;
 		my @pos_names	= $self->variables;
 		foreach my $pos (0 .. $#pos_names) {
 			my $n	= $nodes[ $pos ];
-			if (blessed($n) and $n->does('Attean::API::Variable')) {
-				$n	= undef;
-				$nodes[$pos]	= undef;
-			}
 			if (blessed($n)) {
 				$bound{ $pos_names[$pos] }	= $n;
 			}
 		}
 		
+		my $pattern	= Attean::QuadPattern->new( %bound );
 		return $self->grep(sub {
 			my $q	= shift;
-			foreach my $key (keys %bound) {
-				my $term	= $q->$key();
-				unless ($term->equals( $bound{$key} )) {
-					return 0;
-				}
-			}
-			return 1;
+			my $binding	= $pattern->unify($q);
+			return $binding ? 1 : 0;
 		});
 	}
 }
 
-package Attean::API::TripleIterator 0.027 {
+package Attean::API::TripleIterator 0.030 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StatementIterator';
@@ -424,7 +415,7 @@ package Attean::API::TripleIterator 0.027 {
 	}
 }
 
-package Attean::API::QuadIterator 0.027 {
+package Attean::API::QuadIterator 0.030 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StatementIterator';
@@ -434,7 +425,7 @@ package Attean::API::QuadIterator 0.027 {
 	}
 }
 
-package Attean::API::MixedStatementIterator 0.027 {
+package Attean::API::MixedStatementIterator 0.030 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StringyItemIterator';
@@ -448,7 +439,7 @@ package Attean::API::MixedStatementIterator 0.027 {
 	}
 }
 
-package Attean::API::ResultIterator 0.027 {
+package Attean::API::ResultIterator 0.030 {
 	use Types::Standard qw(Str ArrayRef);
 	use Moo::Role;
 	
@@ -471,9 +462,11 @@ package Attean::API::ResultIterator 0.027 {
 		}
 		return Attean::ListIterator->new( values => \@results, item_type => $self->item_type, variables => \@vars);
 	}
+
+	with 'Attean::API::ResultOrTermIterator';
 }
 
-package Attean::API::TermIterator 0.027 {
+package Attean::API::TermIterator 0.030 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
