@@ -7,7 +7,7 @@ Attean::API::Parser - Parser role
 
 =head1 VERSION
 
-This document describes Attean::API::Parser version 0.026
+This document describes Attean::API::Parser version 0.030
 
 =head1 DESCRIPTION
 
@@ -48,11 +48,17 @@ to this parser.
 Returns a L<Type::Tiny> object representing the type of items that result from
 parsing.
 
+=item C<< file_extensions >>
+
+Returns an ARRAY reference of file extensions commonly associated with the
+media types supported by the parser (and returned by C<< media_types >>).
+File extensions should NOT include a leading dot.
+
 =cut
 
 use Type::Tiny::Role;
 
-package Attean::API::Parser 0.026 {
+package Attean::API::Parser 0.030 {
 	use Types::Standard qw(CodeRef Bool);
 
 	use Moo::Role;
@@ -87,9 +93,11 @@ C<lazy_iris> attribute.
 		}
 		return Attean::IRI->new(%args);
 	}
+	
+	sub file_extensions { return [] }
 }
 
-package Attean::API::AbbreviatingParser 0.026 {
+package Attean::API::AbbreviatingParser 0.030 {
 	use Types::Standard qw(ConsumerOf InstanceOf Maybe);
 	use Types::Namespace qw( NamespaceMap );
 	use Scalar::Util qw(blessed);
@@ -101,7 +109,7 @@ package Attean::API::AbbreviatingParser 0.026 {
 	has 'namespaces'	=> (is => 'ro', isa => Maybe[NamespaceMap]);
 }
 
-package Attean::API::PushParser 0.026 {
+package Attean::API::PushParser 0.030 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 
@@ -165,7 +173,7 @@ package Attean::API::PushParser 0.026 {
 	}
 }
 
-package Attean::API::PullParser 0.026 {
+package Attean::API::PullParser 0.030 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 	
@@ -207,7 +215,7 @@ package Attean::API::PullParser 0.026 {
 	}
 }
 
-package Attean::API::AtOnceParser 0.026 {
+package Attean::API::AtOnceParser 0.030 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 	
@@ -268,7 +276,7 @@ package Attean::API::AtOnceParser 0.026 {
 	
 }
 
-package Attean::API::TermParser 0.026 {
+package Attean::API::TermParser 0.030 {
 	# Parser returns objects that conform to Attean::API::Term
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -278,7 +286,7 @@ package Attean::API::TermParser 0.026 {
 	}
 }
 
-package Attean::API::TripleParser 0.026 {
+package Attean::API::TripleParser 0.030 {
 	# Parser returns objects that conform to Attean::API::Triple
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -288,7 +296,7 @@ package Attean::API::TripleParser 0.026 {
 	}
 }
 
-package Attean::API::QuadParser 0.026 {
+package Attean::API::QuadParser 0.030 {
 	# Parser returns objects that conform to Attean::API::Quad
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -298,7 +306,7 @@ package Attean::API::QuadParser 0.026 {
 	}
 }
 
-package Attean::API::MixedStatementParser 0.026 {
+package Attean::API::MixedStatementParser 0.030 {
 	# Parser returns objects that conform to either Attean::API::Triple or Attean::API::Quad
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -308,7 +316,7 @@ package Attean::API::MixedStatementParser 0.026 {
 	}
 }
 
-package Attean::API::ResultOrTermParser 0.026 {
+package Attean::API::ResultOrTermParser 0.030 {
 	# Parser returns objects that conform to either Attean::API::Result or Attean::API::Term
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -318,7 +326,7 @@ package Attean::API::ResultOrTermParser 0.026 {
 	}
 }
 
-package Attean::API::ResultParser 0.026 {
+package Attean::API::ResultParser 0.030 {
 	# Parser returns objects that conform to Attean::API::Result
 	use Moo::Role;
 	with 'Attean::API::Parser';
