@@ -7,7 +7,7 @@ Attean::CodeIterator - Iterator implementation backed by a generator function
 
 =head1 VERSION
 
-This document describes Attean::CodeIterator version 0.026
+This document describes Attean::CodeIterator version 0.030
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ that will be returned from the iterator.
 
 =cut
 
-package Attean::CodeIterator 0.026 {
+package Attean::CodeIterator 0.030 {
 	use Moo;
 	use Type::Tiny::Role;
 	use Scalar::Util qw(blessed);
@@ -85,7 +85,9 @@ Returns the iterator's next item, or undef upon reaching the end of iteration.
 		}
 		my $role	= $self->item_type;
 		if (Role::Tiny->is_role($role)) {
-			die "CodeIterator item is not a $role: $item" unless (blessed($item) and $item->does($role));
+			unless (blessed($item) and $item->does($role)) {
+				die "CodeIterator item is not a $role: $item";
+			}
 		}
 		return $item;
 	}
