@@ -7,7 +7,7 @@ Attean::Expression - SPARQL Expressions
 
 =head1 VERSION
 
-This document describes Attean::Expression version 0.026
+This document describes Attean::Expression version 0.030
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,7 @@ use Attean::API::Expression;
 
 =cut
 
-package Attean::ValueExpression 0.026 {
+package Attean::ValueExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use AtteanX::SPARQL::Constants;
@@ -50,7 +50,7 @@ package Attean::ValueExpression 0.026 {
 	with 'Attean::API::SPARQLSerializable';
 	with 'Attean::API::Expression';
 
-	has 'value' => (is => 'ro', isa => ConsumerOf['Attean::API::TermOrVariable']);
+	has 'value' => (is => 'ro', isa => ConsumerOf['Attean::API::TermOrVariableOrTriplePattern']);
 
 	sub arity { return 0 }
 	sub BUILDARGS {
@@ -101,7 +101,7 @@ package Attean::ValueExpression 0.026 {
 
 =cut
 
-package Attean::UnaryExpression 0.026 {
+package Attean::UnaryExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(Enum);
 	use namespace::clean;
@@ -138,7 +138,7 @@ package Attean::UnaryExpression 0.026 {
 
 =cut
 
-package Attean::BinaryExpression 0.026 {
+package Attean::BinaryExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(Enum);
 	use namespace::clean;
@@ -166,7 +166,7 @@ package Attean::BinaryExpression 0.026 {
 
 =cut
 
-package Attean::FunctionExpression 0.026 {
+package Attean::FunctionExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(Enum ConsumerOf HashRef);
 	use Types::Common::String qw(UpperCaseStr);
@@ -194,7 +194,7 @@ package Attean::FunctionExpression 0.026 {
 	
 	sub BUILD {
 		my $self	= shift;
-		state $type	= Enum[qw(INVOKE IN NOTIN STR LANG LANGMATCHES DATATYPE BOUND IRI URI BNODE RAND ABS CEIL FLOOR ROUND CONCAT SUBSTR STRLEN REPLACE UCASE LCASE ENCODE_FOR_URI CONTAINS STRSTARTS STRENDS STRBEFORE STRAFTER YEAR MONTH DAY HOURS MINUTES SECONDS TIMEZONE TZ NOW UUID STRUUID MD5 SHA1 SHA256 SHA384 SHA512 COALESCE IF STRLANG STRDT SAMETERM ISIRI ISBLANK ISLITERAL ISNUMERIC REGEX)];
+		state $type	= Enum[qw(INVOKE IN NOTIN STR LANG LANGMATCHES DATATYPE BOUND IRI URI BNODE RAND ABS CEIL FLOOR ROUND CONCAT SUBSTR STRLEN REPLACE UCASE LCASE ENCODE_FOR_URI CONTAINS STRSTARTS STRENDS STRBEFORE STRAFTER YEAR MONTH DAY HOURS MINUTES SECONDS TIMEZONE TZ NOW UUID STRUUID MD5 SHA1 SHA256 SHA384 SHA512 COALESCE IF STRLANG STRDT SAMETERM ISIRI ISBLANK ISLITERAL ISNUMERIC REGEX TRIPLE ISTRIPLE SUBJECT PREDICATE OBJECT)];
 		$type->assert_valid($self->operator);
 	}
 
@@ -230,7 +230,7 @@ package Attean::FunctionExpression 0.026 {
 	}
 }
 
-package Attean::AggregateExpression 0.026 {
+package Attean::AggregateExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(Bool Enum Str HashRef ConsumerOf);
 	use Types::Common::String qw(UpperCaseStr);
@@ -298,7 +298,7 @@ package Attean::AggregateExpression 0.026 {
 	}
 }
 
-package Attean::CastExpression 0.026 {
+package Attean::CastExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(Enum ConsumerOf);
 	use AtteanX::SPARQL::Constants;
@@ -350,7 +350,7 @@ package Attean::CastExpression 0.026 {
 	}
 }
 
-package Attean::ExistsExpression 0.026 {
+package Attean::ExistsExpression 0.030 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -402,7 +402,7 @@ package Attean::ExistsExpression 0.026 {
 	}
 }
 
-package Attean::ExistsPlanExpression 0.026 {
+package Attean::ExistsPlanExpression 0.030 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
