@@ -7,7 +7,7 @@ Attean::Triple - RDF Triples
 
 =head1 VERSION
 
-This document describes Attean::Triple version 0.026
+This document describes Attean::Triple version 0.030
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ This role consumes L<Attean::API::Triple>.
 
 =cut
 
-package Attean::TriplePattern 0.026 {
+package Attean::TriplePattern 0.030 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Attean::RDF;
@@ -56,9 +56,14 @@ package Attean::TriplePattern 0.026 {
 		# TODO: deprecate this in favor of as_quad_pattern() provided by Attean::API::TriplePattern
 		return $self->as_quad_pattern($graph);
 	}
+	
+	sub ntriples_string {
+		my $self	= shift;
+		return join(' ', '<<', (map { $self->$_()->ntriples_string() } qw(subject predicate object)), '>>');
+	}
 }
 
-package Attean::Triple 0.026 {
+package Attean::Triple 0.030 {
 	use Moo;
 	use Attean::API::Binding;
 	
