@@ -4,17 +4,30 @@ AtteanX::Parser::NTriples - N-Triples Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTriples version 0.026
+This document describes AtteanX::Parser::NTriples version 0.030
 
 =head1 SYNOPSIS
 
  use Attean;
  my $parser = Attean->get_parser('NTriples')->new();
+
+ # Parse data from a file-handle and handle triples in the 'handler' callback
  $parser->parse_cb_from_io( $fh );
+ 
+ # Parse the given byte-string, and return an iterator of triples
+ my $iter = $parser->parse_iter_from_bytes('<http://example.org/subject> <tag:example.org:predicate> "object" .');
+ while (my $triple = $iter->next) {
+   print $triple->as_string;
+ }
 
 =head1 DESCRIPTION
 
-...
+This module implements a parser for the N-Triples format.
+
+=head1 ROLES
+
+This class consumes L<Attean::API::Parser>, L<Attean::API::PullParser>
+and <Attean::API::TripleParser>.
 
 =head1 METHODS
 
@@ -25,7 +38,7 @@ This document describes AtteanX::Parser::NTriples version 0.026
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::NTriples 0.026 {
+package AtteanX::Parser::NTriples 0.030 {
 	use utf8;
 	
 	use Attean;
