@@ -7,7 +7,7 @@ AtteanX::Parser::Turtle::Constants - Constant definitions for use in parsing Tur
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle::Constants version 0.026
+This document describes AtteanX::Parser::Turtle::Constants version 0.030
 
 =head1 SYNOPSIS
 
@@ -19,7 +19,7 @@ This document describes AtteanX::Parser::Turtle::Constants version 0.026
 
 =cut
 
-package AtteanX::Parser::Turtle::Constants 0.026 {
+package AtteanX::Parser::Turtle::Constants 0.030 {
 	use v5.14;
 	use warnings;
 
@@ -43,6 +43,7 @@ package AtteanX::Parser::Turtle::Constants 0.026 {
 			LBRACE
 			LBRACKET
 			LPAREN
+			GRAPH
 			PREFIX
 			PREFIXNAME
 			RBRACE
@@ -55,6 +56,10 @@ package AtteanX::Parser::Turtle::Constants 0.026 {
 			STRING3S
 			TURTLEBASE
 			TURTLEPREFIX
+			GTGT
+			LTLT
+			LANNOT
+			RANNOT
 			WS
 			decrypt_constant
 		)
