@@ -4,7 +4,7 @@ AtteanX::Store::Simple - Simple, unindexed, in-memory RDF store
 
 =head1 VERSION
 
-This document describes AtteanX::Store::Simple version 0.026
+This document describes AtteanX::Store::Simple version 0.030
 
 =head1 SYNOPSIS
 
@@ -19,7 +19,7 @@ AtteanX::Store::Simple provides an in-memory quad-store.
 use v5.14;
 use warnings;
 
-package AtteanX::Store::Simple 0.026 {
+package AtteanX::Store::Simple 0.030 {
 	use Moo;
 	use Type::Tiny::Role;
 	use Types::Standard qw(Int ArrayRef HashRef ConsumerOf InstanceOf);
@@ -30,7 +30,7 @@ package AtteanX::Store::Simple 0.026 {
 	use Scalar::Util qw(refaddr reftype blessed);
 	use namespace::clean;
 
-	with 'Attean::API::QuadStore';
+	with 'Attean::API::QuadStore', 'Attean::API::RDFStarStore';
 
 =head1 METHODS
 
